/*
 * ANTSDemultiplexKey.Java
 *
 * Copyright (c) 1999, 2000, 2001, 2002 The University of Utah and the Flux Group.
 * All rights reserved.
 * 
 * This file is part of the ANTS distribution.
 * 
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that (i) the above copyright notice(s)
 * appear in all copies and (ii) that both the copyright notice(s)
 * and this permission notice appear in supporting documentation,
 * and (iii) that the name(s) of the copyright holders not be used
 * in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.  The
 * copyright holders make no representations about the suitability
 * of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 * 
 * The maintainers of this code ask, but do not require, that
 * improvements and bug fixes be emailed to ants-dist@cs.utah.edu
 *         
 */
package ants.core;

import edu.utah.janos.nodeos.DemultiplexKey;
import edu.utah.janos.nodeos.Domain;

/**
 * Match ANTS packets for a specific ANTS protocol.
 *
 * @author <a href="mailto:janos-discuss@flux.cs.utah.edu">Utah Janos Team</a>
 */
class ANTSDemultiplexKey
    extends ANEPDemultiplexKey
{
    ANTSDemultiplexKey(Domain domain, TypeID mid)
    {
	this(domain, mid.unwrap());
    }
    
    ANTSDemultiplexKey(Domain domain, byte[] midBytes)
    {
	/*
	 * Match the ANEP header.
	 */
	super(domain, Capsule.getAnepTypeID());

	/* Offset += 4 */
	this.add(4, null, null);
	/*
	 * Add a match for the MID, XXX skipping the four-byte
	 * ANTS version number that preceeds a MID.
	 */
	this.add(midBytes.length, midBytes, null);
    }
    
    /**
     * Useful for subclasses mostly.
     */
    public int whereDoesTheCapsuleDecodingActuallyStart(int payloadStart)
    {
	return payloadStart;
    }

    public String toString()
    {
	return "ANTSDemultiplexKey["
	    + super.toString()
	    + "]";
    }
}
