/*
 * AppConfig.Java
 *
 * Copyright (c) 1999, 2000, 2001 The University of Utah and the Flux Group.
 * All rights reserved.
 * 
 * This file is part of the ANTS distribution.
 * 
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that (i) the above copyright notice(s)
 * appear in all copies and (ii) that both the copyright notice(s)
 * and this permission notice appear in supporting documentation,
 * and (iii) that the name(s) of the copyright holders not be used
 * in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.  The
 * copyright holders make no representations about the suitability
 * of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 * 
 * The maintainers of this code ask, but do not require, that
 * improvements and bug fixes be emailed to ants-dist@cs.utah.edu
 *         
 */
package ants.core;

/**
 * A simple (classname, arguments) pair.  For some reason we
 * duplicate the className in the arguments passed.
 *
 * XXX this.className isn't really necessary.  Delete it.
 *
 * @author <a href="mailto:janos-discuss@flux.cs.utah.edu">Utah Janos Team</a>
 */
class AppConfig
{
    private final String className;
    private final String[] args;
    
    /*package*/ AppConfig(String className, String[] args, int argsStart)
    {
	Assert.require(className);
	Assert.require(args);
	Assert.require(argsStart >= 0);
	
	Trace.trace(Trace.ANTS_APP, "Creating app cfg " +className+ " with args.length=" +args.length+ "; argsStart=" +argsStart);
	// for (int i = argsStart; i < args.length; i++)
	// {
	// 	   Trace.trace(Trace.ANTS_APP, "  [" +i+ "] " +args[i]);
	// }
	
	this.className = className;
	this.args = new String[args.length - argsStart + 1];
	this.args[0] = className;
	
	System.arraycopy(args, argsStart,
			 this.args, 1, this.args.length - 1);
	
	Assert.ensure(this.className);
	Assert.ensure(this.args);
    }
    
    public String className()
    {
	Assert.require(this.className);
	return this.className;
    }
    
    public String[] args()
    {
	Assert.require(this.args);
	return this.args;
    }
    
    public String toString()
    {
	String retval;
	int lpc;
	
	retval = "AppConfig[className="
	    + this.className
    + "; args[]={";
	for( lpc = 0; lpc < this.args.length; lpc++ )
	{
	    if( lpc > 0 )
		retval += ", ";
	    retval += this.args[lpc];
	}
	retval += "}";
	retval += "]";
	
	return retval;
    }
}
