/* 
 * NodeAddress.java
 *
 * Copyright (c) 1999, 2001 The University of Utah and the Flux Group.
 * All rights reserved.
 * 
 * This file is part of the ANTS distribution.
 * 
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that (i) the above copyright notice(s)
 * appear in all copies and (ii) that both the copyright notice(s)
 * and this permission notice appear in supporting documentation,
 * and (iii) that the name(s) of the copyright holders not be used
 * in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.  The
 * copyright holders make no representations about the suitability
 * of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 * 
 * The maintainers of this code ask, but do not require, that
 * improvements and bug fixes be emailed to ants-dist@cs.utah.edu
 *         
 *  
 *  Copyright 1996 Massachusetts Institute of Technology
 * 
 *  Permission to use, copy, modify, distribute, and sell this software and
 *  its documentation for any purpose is hereby granted without fee, provided
 *  that the above copyright notice appear in all copies and that both that
 *  copyright notice and this permission notice appear in supporting
 *  documentation, and that the name of M.I.T. not be used in advertising or
 *  publicity pertaining to distribution of the software without specific,
 *  written prior permission.  M.I.T. makes no representations about the
 *  suitability of this software for any purpose.  It is provided "as is"
 *  without express or implied warranty.
 * 
 */
package ants.core;

import edu.utah.janos.nodeos.Address;
import edu.utah.janos.nodeos.AddressFormatException;

/**
 * Routines for manipulating node addresses.  A node address is 
 * simply a 32 bit integer for efficiency, but these convenience
 * routines exist to convert to and from printed representations
 * and so on.
 * <p>
 * This is just here (in ANTS) for compatiblity.  All the functions
 * are in the Janos Java NodeOS.
 *
 * @author David Wetherall
 * @author <a href="mailto:janos-discuss@flux.cs.utah.edu">Utah Janos Team</a>
 */
public class NodeAddress {
    
    /**
     * Insubstantiable
     */
    private NodeAddress()
    {
    }
    
    /**
     * Determine if the given integer address is a multicast address.
     */
    public final static boolean multicast(int a) {
	// XXX move into Address
	return ((a & 0xF0000000) == 0xE0000000);
    }
    
    /**
     * Generate a string representation of the given address.
     * Generates standard dotted-quad notation.
     */
    public final static String toString(int a)
    {
	return Address.toString(a);
    }
    
    /**
     * Generate a 32-bit integer from the given string address.
     * The string must be a dotted-quad.
     *
     * @exception AddressFormatException if there aren't 4 parts, any of the 4 parts don't parse,
     * or are out of range.
     */
    public static int fromString(String name)
	throws AddressFormatException
    {
	return Address.fromString(name);
    }
}
