/*
 * ProtocolRegister.Java
 *
 * Copyright (c) 1999, 2000, 2001 The University of Utah and the Flux Group.
 * All rights reserved.
 * 
 * This file is part of the ANTS distribution.
 * 
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that (i) the above copyright notice(s)
 * appear in all copies and (ii) that both the copyright notice(s)
 * and this permission notice appear in supporting documentation,
 * and (iii) that the name(s) of the copyright holders not be used
 * in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.  The
 * copyright holders make no representations about the suitability
 * of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 * 
 * The maintainers of this code ask, but do not require, that
 * improvements and bug fixes be emailed to ants-dist@cs.utah.edu
 *         
 */
package ants.core;

import edu.utah.janos.nodeos.InfoHook;
import edu.utah.janos.nodeos.Status;

import edu.utah.janos.io.Log;

import java.util.Enumeration; // XXX
import java.util.Hashtable; // XXX


/**
 * Maintain a map of all the Protocols in the system.
 *
 * @author <a href="mailto:janos-discuss@flux.cs.utah.edu">Utah Janos Team</a>
 */
class ProtocolRegister
{
    private static final Hashtable protocols = new Hashtable();
    
    /**
     * A simple class used to define the owner of a protocol.
     */
    public static class Owner
    {
	public String id;
	public String data;
	
	public Owner(String id, String data)
	{
	    this.id = id;
	    this.data = data;
	}
	
	public String toString()
	{
	    return "ProtocolRegister.Owner[id="+id+";data="+data+"]";
	}
    }
    
    private static class ProtocolInfo
	extends InfoHook
    {
	public ProtocolInfo()
	{
	    super("Protocols");
	}
	
	public String[] getInfo()
	{
	    String retval[];
	    
	    synchronized(protocols)
	    {
		retval = new String[protocols.size()];
		Enumeration enum = protocols.elements();
		int i;
		
		for( i = 0; i < protocols.size(); i++ )
		{
		    Owner o = (Owner)enum.nextElement();
		    
		    retval[i] = "id="
			+ o.id
    + "; data="
    + o.data;
		}
	    }
	    return retval;
	}
    }
    
    static {
	Status.addInfoHook(new ProtocolInfo());
    }
    
    /**
     * Register a protocol, the protocol had best not be registered
     * by someone else already.
     *
     * @param id An object used to identify a protocol
     * @param owner The entity that owns the protocol
     * @return The current owner or null, if none
     */
    static void register(Object id, Owner owner)
    {
	Object existingVal;
	
	Assert.require(id);
	Assert.require(owner);
	
	synchronized(protocols)
	{
	    existingVal = ProtocolRegister.protocols.put(id, owner);
	}
	
	if (existingVal != null)
	{
	    PrimordialNode.message(Log.ERR,
				   "ProtocolRegister.register(id   =" +id+
				   ",owner=" +owner+ ") hit existing duplicate.");
	    Node.abort("ProtocolRegsiter got duplicate registration for " +existingVal);
	}
    }
}
