/* 
 * PongCapsule.Java
 *
 * Copyright (c) 1999, 2000 The University of Utah and the Flux Group.
 * All rights reserved.
 * 
 * This file is part of the ANTS distribution.
 * 
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that (i) the above copyright notice(s)
 * appear in all copies and (ii) that both the copyright notice(s)
 * and this permission notice appear in supporting documentation,
 * and (iii) that the name(s) of the copyright holders not be used
 * in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.  The
 * copyright holders make no representations about the suitability
 * of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 * 
 * The maintainers of this code ask, but do not require, that
 * improvements and bug fixes be emailed to ants-dist@cs.utah.edu
 *         
 *  
 *  Copyright 1996 Massachusetts Institute of Technology
 * 
 *  Permission to use, copy, modify, distribute, and sell this software and
 *  its documentation for any purpose is hereby granted without fee, provided
 *  that the above copyright notice appear in all copies and that both that
 *  copyright notice and this permission notice appear in supporting
 *  documentation, and that the name of M.I.T. not be used in advertising or
 *  publicity pertaining to distribution of the software without specific,
 *  written prior permission.  M.I.T. makes no representations about the
 *  suitability of this software for any purpose.  It is provided "as is"
 *  without express or implied warranty.
 */
package apps.pong;

import ants.core.Protocol;
import ants.core.DataCapsule;
import ants.core.Xdr;
import ants.core.Node;
import ants.core.ByteArray;

/**
 * Pong capsule.
 *
 * @author <a href="mailto:djw@cs.washington.edu">David Wetherall</a>
 * @author <a href="mailto:janos-discuss@flux.cs.utah.edu">Utah Janos Team</a> 
 */
public class PongCapsule
    extends DataCapsule
{
    final private static byte[] MID = findMID("apps.pong" + ".PongCapsule");
    final private static byte[] PID = findPID("apps.pong" + ".PongCapsule");
    
    protected byte[] mid()
    {
	return MID;
    }
    
    protected byte[] pid()
    {
	return PID;
    }
    
    public boolean pong = false;
    
    /**
     * Sequence number for the pong capsule.  
     */
    public int seqId;
    
    public int length()
    {
	return super.length() + Xdr.BOOLEAN + Xdr.INT;
    }
    
    public Xdr encode()
    {
	Xdr xdr = super.encode();
	xdr.PUT(pong);
	xdr.PUT(seqId);
	
	return xdr;
    }
    
    public Xdr decode()
    {
	Xdr xdr = super.decode();
	pong = xdr.BOOLEAN();
	seqId = xdr.INT();
	
	return xdr;
    }
    
    public boolean evaluate(Node n)
    {
	PongHelper ph = new PongHelper();
	
	ph.setDummy1(0);
	ph.setDummy2(1);
	if( ph.getDummy1() != 0 )
	    throw new InternalError();
	if( ph.getDummy2() != 1 )
	    throw new InternalError();
	if (n.getAddress() == getDst())
	{
	    pong = true;      
	}
	else if (pong!=true)
	{
	    return n.routeForNode(this, getDst());
	} 
	
	if (n.getAddress() == getSrc()) 
	{
	    return n.deliverToApp(this, dpt);
	}
	else if (pong)
	{
	    return n.routeForNode(this, getSrc());
	}
	
	return false; 
    }
    
    public PongCapsule()
    {
    }
    
    public PongCapsule(short sa, short da, int na, ByteArray d)
    {
	super(sa, da, na, d);
    }
}

