/*
 * Tester.Java
 *
 * Copyright (c) 2000, 2001 The University of Utah and the Flux Group.
 * All rights reserved.
 *
 * This file is part of the ANTS distribution.
 * 
 * Permission to use, copy, modify, distribute, and sell this
 * software and its documentation for any purpose is hereby granted
 * without fee, provided that (i) the above copyright notice(s)
 * appear in all copies and (ii) that both the copyright notice(s)
 * and this permission notice appear in supporting documentation,
 * and (iii) that the name(s) of the copyright holders not be used
 * in advertising or publicity pertaining to distribution of the
 * software without specific, written prior permission.  The
 * copyright holders make no representations about the suitability
 * of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 * 
 * The maintainers of this code ask, but do not require, that
 * improvements and bug fixes be emailed to ants-dist@cs.utah.edu
 *         
 */

package tests;

import edu.utah.janos.nodeos.Node;
import edu.utah.janos.nodeos.Domain;
import edu.utah.janos.nodeos.DomainRun;

import edu.utah.janosvm.kit.comm.commspace.CommSpaceHandle;

import ants.core.Application;

public abstract class Tester
    extends Application
{
    public void start()
    {
	Tester.doTests(this);
    }
    
    public static void doTests(Tester unit)
    {
	try
	{
	    unit.testUnit();
	}
	catch (TestFailedException tfe)
	{
	    Throwable inner;
	    inner = tfe.getInner();
	    
	    Node.println("Test failed: " +tfe);
	    if (inner == null)
	    {
		Node.printStackTrace(tfe);
	    }
	    else
	    {
		Node.println("Inner:");
		Node.printStackTrace(inner);
		Node.println("TFE:");
		Node.printStackTrace(tfe);
	    }
	}
	catch (Throwable th)
	{
	    Node.println("Test failed: " +th);
	    Node.printStackTrace(th);
	}
	Node.shutdown();
    }
    
    public void test(boolean t)
	throws TestFailedException
    {
	if (!t)
	{
	    throw new TestFailedException("boolean test failed");
	}
    }
    
    public void enterSection(String name)
    {
	Node.println("Entering test section: " +name);
    }
    
    public abstract void testUnit()
	throws TestFailedException;
}
